.. apy documentation master file, created by
   sphinx-quickstart on Wed Dec  3 12:07:13 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

=================
Qarnot Python SDK
=================

qarnot is a Python library designed to interact with |QarnotLink| cloud computing service. It allows users to launch, manage and monitor payloads running on distributed computing nodes deployed in Qarnot's digital heaters.

You can find samples and detailed information on http://computing.qarnot.com.

Reference Docs
==============

.. toctree::
   :maxdepth: 1

   installation
   basic
   qarnot


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

  .. |QarnotLink| raw:: html

   <a href="http://qarnot-computing.com" target="_blank">Qarnot</a>
